@@ -7,6 +7,7 @@ import (
 
 	"github.com/stretchr/testify/assert"
 
+	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/syft/syft/artifact"
 	"github.com/anchore/syft/syft/cpe"
 	"github.com/anchore/syft/syft/file"
@@ -376,7 +377,7 @@ func TestNew(t *testing.T) {
 			},
 		},
 		{
-			name: "dart-pub-metadata",
+			name: "dart-publock-metadata",
 			syftPkg: syftPkg.Package{
 				Metadata: syftPkg.DartPubspecLockEntry{
 					Name:    "a",
@@ -384,6 +385,33 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "dart-pubspec-metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.DartPubspec{
+					Homepage:      "a",
+					Repository:    "a",
+					Documentation: "a",
+					PublishTo:     "a",
+					Environment: &syftPkg.DartPubspecEnvironment{
+						SDK:     "a",
+						Flutter: "a",
+					},
+					Platforms:         []string{"a"},
+					IgnoredAdvisories: []string{"a"},
+				},
+			},
+		},
+		{
+			name: "homebrew-formula-metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.HomebrewFormula{
+					Tap:         "a",
+					Homepage:    "a",
+					Description: "a",
+				},
+			},
+		},
 		{
 			name: "dotnet-metadata",
 			syftPkg: syftPkg.Package{
@@ -694,7 +722,7 @@ func TestNew(t *testing.T) {
 			},
 		},
 		{
-			name: "Php-pecl-entry",
+			name: "php-pecl-entry",
 			syftPkg: syftPkg.Package{
 				Metadata: syftPkg.PhpPeclEntry{
 					Name:    "a",
@@ -703,6 +731,15 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "php-pear-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.PhpPearEntry{
+					Name:    "a",
+					Version: "a",
+				},
+			},
+		},
 		{
 			name: "lua-rocks-entry",
 			syftPkg: syftPkg.Package{
@@ -805,6 +842,76 @@ func TestNew(t *testing.T) {
 				},
 			},
 		},
+		{
+			name: "pe binary metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.PEBinary{
+					VersionResources: syftPkg.KeyValues{
+						{
+							Key:   "k",
+							Value: "k",
+						},
+					},
+				},
+			},
+		},
+		{
+			name: "uv lock metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.PythonUvLockEntry{
+					Index: "https://pypi.org/simple",
+					Dependencies: []syftPkg.PythonUvLockDependencyEntry{
+						{Name: "certifi"},
+						{Name: "charset-normalizer"},
+						{Name: "idna"},
+						{Name: "urllib3"},
+					},
+				},
+			},
+		},
+		{
+			name: "conda meta package metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.CondaMetaPackage{
+					Name:        "numpy",
+					Version:     "1.21.0",
+					Build:       "py39h20b1b1c_0",
+					BuildNumber: 0,
+					Channel:     "conda-forge",
+				},
+			},
+		},
+		{
+			name: "golang source entry metadata",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.GolangSourceEntry{
+					H1Digest:        "h1:some-hash-value",
+					OperatingSystem: "linux",
+					Architecture:    "amd64",
+					BuildTags:       "release",
+					CgoEnabled:      true,
+				},
+			},
+			metadata: GolangSourceMetadata{
+				H1Digest:        "h1:some-hash-value",
+				OperatingSystem: "linux",
+				Architecture:    "amd64",
+				BuildTags:       "release",
+				CgoEnabled:      true,
+			},
+		},
+		{
+			name: "snap-entry",
+			syftPkg: syftPkg.Package{
+				Metadata: syftPkg.SnapEntry{
+					SnapType:     "app",
+					Base:         "core22",
+					SnapName:     "test-snap",
+					SnapVersion:  "1.0.0",
+					Architecture: "amd64",
+				},
+			},
+		},
 	}
 
 	// capture each observed metadata type, we should see all of them relate to what syft provides by the end of testing
@@ -974,22 +1081,44 @@ func Test_RemovePackagesByOverlap(t *testing.T) {
 		},
 		{
 			name: "python bindings for system RPM install",
-			sbom: withDistro(catalogWithOverlaps(
+			sbom: withLinuxRelease(catalogWithOverlaps(
 				[]string{"rpm:python3-rpm@4.14.3-26.el8", "python:rpm@4.14.3"},
 				[]string{"rpm:python3-rpm@4.14.3-26.el8 -> python:rpm@4.14.3"}), "rhel"),
 			expectedPackages: []string{"rpm:python3-rpm@4.14.3-26.el8"},
 		},
 		{
 			name: "amzn linux doesn't remove packages in this way",
-			sbom: withDistro(catalogWithOverlaps(
+			sbom: withLinuxRelease(catalogWithOverlaps(
 				[]string{"rpm:python3-rpm@4.14.3-26.el8", "python:rpm@4.14.3"},
 				[]string{"rpm:python3-rpm@4.14.3-26.el8 -> python:rpm@4.14.3"}), "amzn"),
 			expectedPackages: []string{"rpm:python3-rpm@4.14.3-26.el8", "python:rpm@4.14.3"},
 		},
+		{
+			name: "remove overlapping package when parent version is prefix of child version",
+			sbom: withLinuxRelease(catalogWithOverlaps(
+				[]string{"rpm:kernel-rt-core@5.14.0-503.40.1.el9_5", "linux-kernel:linux-kernel@5.14.0-503.40.1.el9_5.x86_64+rt"},
+				[]string{"rpm:kernel-rt-core@5.14.0-503.40.1.el9_5 -> linux-kernel:linux-kernel@5.14.0-503.40.1.el9_5.x86_64+rt"}), "rhel"),
+			expectedPackages: []string{"rpm:kernel-rt-core@5.14.0-503.40.1.el9_5"},
+		},
+		{
+			name: "remove overlapping package when child version is prefix of parent version",
+			sbom: withLinuxRelease(catalogWithOverlaps(
+				[]string{"rpm:kernel-rt-core@5.14.0-503.40.1.el9_5+rt", "linux-kernel:linux-kernel@5.14.0-503.40.1.el9_5"},
+				[]string{"rpm:kernel-rt-core@5.14.0-503.40.1.el9_5+rt -> linux-kernel:linux-kernel@5.14.0-503.40.1.el9_5"}), "rhel"),
+			expectedPackages: []string{"rpm:kernel-rt-core@5.14.0-503.40.1.el9_5+rt"},
+		},
+		{
+			name: "do not remove overlapping package when versions are not similar",
+			sbom: withLinuxRelease(catalogWithOverlaps(
+				[]string{"rpm:kernel@5.14.0-503.40.1.el9_5", "linux-kernel:linux-kernel@6.17"},
+				[]string{"rpm:kernel@5.14.0-503.40.1.el9_5 -> linux-kernel:linux-kernel@6.17"}), "rhel"),
+			expectedPackages: []string{"rpm:kernel@5.14.0-503.40.1.el9_5", "linux-kernel:linux-kernel@6.17"},
+		},
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			catalog := removePackagesByOverlap(test.sbom.Artifacts.Packages, test.sbom.Relationships, test.sbom.Artifacts.LinuxDistribution)
+			d := distro.FromRelease(test.sbom.Artifacts.LinuxDistribution, distro.DefaultFixChannels())
+			catalog := removePackagesByOverlap(test.sbom.Artifacts.Packages, test.sbom.Relationships, d)
 			pkgs := FromCollection(catalog, SynthesisConfig{})
 			var pkgNames []string
 			for _, p := range pkgs {
@@ -1070,7 +1199,7 @@ func catalogWithOverlaps(packages []string, overlaps []string) *sbom.SBOM {
 	}
 }
 
-func withDistro(s *sbom.SBOM, id string) *sbom.SBOM {
+func withLinuxRelease(s *sbom.SBOM, id string) *sbom.SBOM {
 	s.Artifacts.LinuxDistribution = &linux.Release{
 		ID: id,
 	}
